from typing import Optional, Any, Iterable

import typer
import yaml


def create_dict_with_depth(
    source: Iterable | Any,
    current_depth: int,
    destination_depth: int,
    include_value: bool,
) -> dict | list | Any:
    if include_value and not isinstance(source, Iterable):
        return source
    if current_depth > destination_depth:
        return None

    if isinstance(source, dict):
        output = {}
        for k, v in source.items():
            output[k] = create_dict_with_depth(
                v, current_depth + 1, destination_depth, include_value
            )
    elif isinstance(source, list):
        output = []
        for item in source:
            output.append(
                create_dict_with_depth(
                    item, current_depth, destination_depth, include_value
                )
            )
    else:
        output = source
    return output


def format_result(result: str) -> str:
    result = result.replace("null", "")
    return result


def main(
    file_path: str,
    depth: Optional[int] = typer.Option(0, "-d", min=0),
    include_value: Optional[bool] = typer.Option(False, "--value", "-v"),
) -> None:
    with open(file_path, "r") as f:
        data = yaml.safe_load(f)
        if depth:
            output = create_dict_with_depth(data, 1, depth, include_value)
            result = yaml.dump(output, default_flow_style=False)
        else:
            result = yaml.dump(data, default_flow_style=False)
        result = format_result(result)
        print(result)


def run():
    typer.run(main)


if __name__ == "__main__":
    run()



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['print_yaml']

package_data = \
{'': ['*']}

install_requires = \
['PyYAML>=6.0,<7.0', 'typer[all]>=0.6.1,<0.7.0']

entry_points = \
{'console_scripts': ['print_yaml = print_yaml.main:run']}

setup_kwargs = {
    'name': 'print-yaml',
    'version': '0.1.0',
    'description': '',
    'long_description': '# print-yaml\n\nprint-yaml is a CLI tool that prints yaml files according to the desired depth.\n\n## Installation\n\n```\n# using pip\n$ pip install print_yaml\n\n# using poetry\n$ poetry add print_yaml\n```\n\n## Usage\n\nLet\'s say you have the following yaml file.\n\n```yaml\n# data.yaml\n\na:\n  b: 1\n  c:\n    - one\n    - two\n    - three:\n        A: 6\n        B: 7\n    - four:\n        - 8\n        - 9\n  d:\n    e: 3\n    f: 4\ng: 5\n```\n\n### Basic\n\nThe following values can be obtained using `print_yaml`\n\n```bash\n$ print_yaml tests/data.yaml -d 1\n\na: \ng: \n```\n\n\n```bash\n$ print_yaml tests/data.yaml -d 2\n\na:\n  b: \n  c: \n  d: \ng: 5\n```\n\n```bash\n$ print_yaml tests/data.yaml -d 3\n\na:\n  b: 1\n  c:\n  - one\n  - two\n  - three: \n  - four: \n  d:\n    e: \n    f: \ng: 5\n```\n\n### With value\n\nBy default, only the "key" in the yaml file is output.  \nIf you add the \'--value\' or \'-v\' option, it also outputs a single value.\n\n```bash\n$ print_yaml tests/data.yaml -d 1 -v\n\na: \ng: 5\n```\n\n```bash\n$ print_yaml tests/data.yaml -d 2 -v\na:\n  b: 1\n  c: \n  d: \ng: 5\n```\n\n```bash\n$ print_yaml tests/data.yaml -d 3 -v\na:\n  b: 1\n  c:\n  - one\n  - two\n  - three: \n  - four: \n  d:\n    e: 3\n    f: 4\ng: 5\n```\n\n### All Commands\n\n```bash\n$ print_yaml --help\n                                                                                                             \n Usage: print_yaml [OPTIONS] FILE_PATH                                                                       \n                                                                                                             \n╭─ Arguments ───────────────────────────────────────────────────────────────────────────────────────────────╮\n│ *    file_path      TEXT  [default: None] [required]                                                      │\n╰───────────────────────────────────────────────────────────────────────────────────────────────────────────╯\n╭─ Options ─────────────────────────────────────────────────────────────────────────────────────────────────╮\n│                       -d      INTEGER RANGE [x>=0]  [default: 0]                                          │\n│ --value               -v                                                                                  │\n│ --install-completion                                Install completion for the current shell.             │\n│ --show-completion                                   Show completion for the current shell, to copy it or  │\n│                                                     customize the installation.                           │\n│ --help                                              Show this message and exit.                           │\n╰───────────────────────────────────────────────────────────────────────────────────────────────────────────╯\n```\n',
    'author': 'heumsi',
    'author_email': 'heumsi@naver.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)
